<?php

namespace Slovocast;

use Slim\App;
use Slovocast\Controller\HomePage;
use Slovocast\Controller\HealthCheck;
use Slovocast\Controller\DashboardPage;
use Slovocast\Controller\User\RegisterUserPage;
use Slovocast\Controller\User\RegisterUserAction;
use Slovocast\Controller\User\LoginUserPage;
use Slovocast\Controller\User\LoginUserAction;
use Slovocast\Middleware\VerifyPasswordMiddleware;
use Slovocast\Middleware\AuthenticatedMiddleware;

class Routes
{
    /**
     * @param App $app Instantiated Application
     * @return void
     */
    public static function init(App $app): void
    {
        $app->get('/', HomePage::class);
        $app->get('/healthcheck', HealthCheck::class);
        // User Routes
        self::users($app);
    }

    /**
     * @param App $app Instantiated Application
     * @return void
     */
    protected static function users(App $app): void
    {
        $app->get('/users/register', RegisterUserPage::class)
            ->setName('user-register-page');
        $app->post('/users/register', RegisterUserAction::class)
            ->add(VerifyPasswordMiddleware::class)
            ->setName('user-register-action');

        $app->get('/login', LoginUserPage::class)
            ->setName('user-login-page');
        $app->post('/login', LoginUserAction::class)
            ->add(AuthenticatedMiddleware::class)
            ->setName('user-login-action');

        $app->get('/dashboard', DashboardPage::class)
            ->add(AuthenticatedMiddleware::class)
            ->setName('user-dashboard');
    }
}
